## Working with Docker images

- `docker images list` # list all images
- `docker images list -a` # list all images including intermediate images
- `docker images rm <image_id>` # remove image
- `docker images prune` # remove all unused images
- `docker image build -t <image_name> <path_to_Dockerfile>` # build an image from a Dockerfile

## Working with Docker containers

- `docker container ls -a` # list all containers including stopped containers
- `docker container rm <container_id>` # remove container
- `docker container prune` # remove all stopped containers
- `docker container stop <container_id>` # stop container
- `docker container start <container_id>` # start container
- `docker container run -d -p 6379:6379 --name redis redis` # run redis container in detached mode 
- `docker container run -d -p 5000:5000 --name qna_app qna_app` # run qna_app container in detached mode
- `docker container run -d -p 5000:5000 --name qna_app --link redis:redis qna_app` # run qna_app container in detached mode and link it to redis container
- `docker container run -d -p 5000:5000 --name qna_app --link redis:redis -e REDIS_HOST=redis qna_app` # run qna_app container in detached mode and link it to redis container and set environment variable REDIS_HOST to redis

## Working with Docker volumes

- `docker volume ls` # list all volumes
- `docker volume rm <volume_name>` # remove volume
- `docker volume prune` # remove all unused volumes
- `docker volume create <volume_name>` # create volume
- `docker volume inspect <volume_name>` # inspect volume
- `docker volume inspect <volume_name> -f '{{.Mountpoint}}'` # inspect volume and get mountpoint

## Working with Docker networks

- `docker network ls` # list all networks
- `docker network rm <network_name>` # remove network
- `docker network prune` # remove all unused networks
- `docker network create <network_name>` # create network
- `docker network inspect <network_name>` # inspect network
- `docker network inspect <network_name> -f '{{.Mountpoint}}'` # inspect network and get mountpoint

## Working with Docker registry

- `docker login` # login to Docker registry
- `docker logout` # logout from Docker registry
- `docker push <image_name>` # push image to Docker registry
- `docker pull <image_name>` # pull image from Docker registry
- `docker search <image_name>` # search for image in Docker registry
- `docker tag <source_image> <target_image>` # tag an image for upload to Docker registry

## Working with docker compose

- `docker compose up -d` # run docker compose in detached mode
- `docker compose down` # stop and remove containers
- `docker compose ps` # list containers
- `docker compose logs` # show logs
- `docker compose logs -f` # show logs and follow
- `docker compose logs -f <service_name>` # show logs for specific service and follow
